/*
jViewBox 2.0 beta

COPYRIGHT NOTICE
Copyright (c) 2003  Jack C. Wei, Scott C. Neu, and Daniel J. Valentino

See README.license for license notices.
 */

package tools;

import java.awt.event.MouseEvent;
import java.util.Iterator;
import org.medtoolbox.jviewbox.viewport.Viewport;
import org.medtoolbox.jviewbox.viewport.ViewportCluster;
import org.medtoolbox.jviewbox.viewport.ViewportState;
import org.medtoolbox.jviewbox.viewport.ViewportTool;

/**
 * Tool for copying the viewing state (e.g., window/level, scale,
 * pan) of one Viewport in a ViewportCluster to all the other Viewports
 * in the same ViewportCluster.
 * <p>
 * When the mouse cursor is clicked on a Viewport, the viewing state currently
 * used by that Viewport is copied to all the other Viewports in the same
 * ViewportCluster.
 *
 * @version January 8, 2004
 */
public class GlobalizeTool extends ViewportTool
{
    /** Constructs a GlobalizeTool. */
    public GlobalizeTool()
    {
	super("Globalize Tool", "Globalize Image Display Settings", "", "");
    }

    /**
     * Invoked when a mouse button is clicked (pressed and released without
     * movement in between) on a ViewportCluster.
     *
     * @param vpc ViewportCluster which received the event.
     * @param vp Viewport which the mouse cursor was on during the event;
     *		 <code>null</code> if the mouse was outside all visible
     *		 Viewports in the ViewportCluster.
     * @param e Event created by the button click.
     * @param button The button that was clicked.
     */
    public void mouseClicked(ViewportCluster vpc, Viewport vp, MouseEvent e, 
			     int button)
    {
	if (vp != null && vpc != null) {

	    // Copy the state to all other Viewports, taking advantage of
	    // Viewport.copyStateFrom()'s no-self-copying defense
	    for (Iterator it = vpc.getViewports().iterator(); it.hasNext(); ) {
		((Viewport)it.next()).copyStateFrom(vp);
	    }

	    // Repaint the ViewportCluster
	    vpc.repaint();
	}
    }
}
