/*
jViewBox 2.0 beta

COPYRIGHT NOTICE
Copyright (c) 2003  Jack C. Wei, Scott C. Neu, and Daniel J. Valentino

See README.license for license notices.
 */

package tools;

import java.awt.Point;
import java.awt.event.MouseEvent;
import org.medtoolbox.jviewbox.viewport.Viewport;
import org.medtoolbox.jviewbox.viewport.ViewportCluster;
import org.medtoolbox.jviewbox.viewport.ViewportTool;

/**
 * Tool for panning an image inside a Viewport.
 * <p>
 * When the mouse cursor is pressed and dragged in a Viewport, the image in 
 * the Viewport moves along with the cursor until the mouse button is released.
 *
 * @version January 8, 2004
 */
public class PanTool extends ViewportTool
{
    /** Anchor point relative to which the pan offset is calculated. */
    private final Point _anchor = new Point();

    /** Viewport being panned. */
    private Viewport _vp = null;

    /** Constructs a PanTool. */
    public PanTool()
    {
	super("Pan Tool", "Pan an Image", "", "");
    }


    /**
     * Invoked when a mouse button is pressed on a ViewportCluster.
     *
     * @param vpc ViewportCluster which received the event.
     * @param vp Viewport which the mouse cursor was on during the event;
     *		 <code>null</code> if the mouse was outside all visible
     *		 Viewports in the ViewportCluster.
     * @param e Event created by the button press.
     * @param button The button that was pressed.
     */
    public void mousePressed(ViewportCluster vpc, Viewport vp, MouseEvent e, 
			     int button)
    {
	_vp = vp;

	if (_vp != null) {
	    // Set the anchor
	    _anchor.x = e.getX() - _vp.getPanX();
	    _anchor.y = e.getY() - _vp.getPanY();

	    // Save the current state
	    _vp.saveCurrentState();

	}
    }

    /**
     * Invoked when a mouse button is pressed and then the mouse is dragged
     * on a ViewportCluster.
     *
     * @param vpc ViewportCluster which received the event.
     * @param vp Viewport which the mouse cursor was on during the event;
     *		 <code>null</code> if the mouse was outside all visible
     *		 Viewports in the ViewportCluster.
     * @param e Event created by the button drag.
     * @param button The button that was pressed and dragged.
     */
    public void mouseDragged(ViewportCluster vpc, Viewport vp, MouseEvent e, 
			     int button)
    {
	if (_vp != null && vpc != null) {

	    // Set the new pan
	    _vp.setPan(e.getX() - _anchor.x, e.getY() - _anchor.y);

	    vpc.repaint(_vp);

	}
    }

}
