/*
jViewBox 2.0 beta

COPYRIGHT NOTICE
Copyright (c) 2003  Jack C. Wei, Scott C. Neu, and Daniel J. Valentino

See README.license for license notices.
 */

package tools;

import java.awt.event.MouseEvent;
import org.medtoolbox.jviewbox.viewport.Viewport;
import org.medtoolbox.jviewbox.viewport.ViewportCluster;
import org.medtoolbox.jviewbox.viewport.ViewportTool;

/**
 * Tool for rotating an image inside a Viewport 90 degrees.
 * <p>
 * When the mouse cursor is clicked on a Viewport, the image in the Viewport
 * will be rotated 90 degrees, clockwise if the left button is clicked and
 * counter-clockwise if any other button is clicked.
 *
 * @version January 8, 2004
 */
public class Rotate90Tool extends ViewportTool
{
    /** Constructs a Rotate90Tool. */
    public Rotate90Tool()
    {
	super("Rotate 90 Tool", "Rotate an Image 90 Degrees Clockwise",
	      "Rotate an Image 90 Degrees Counter-clockwise",
	      "Rotate an Image 90 Degrees Counter-clockwise");
    }

    /**
     * Invoked when a mouse button is clicked (pressed and released without
     * movement in between) on a ViewportCluster.
     *
     * @param vpc ViewportCluster which received the event.
     * @param vp Viewport which the mouse cursor was on during the event;
     *		 <code>null</code> if the mouse was outside all visible
     *		 Viewports in the ViewportCluster.
     * @param e Event created by the button click.
     * @param button The button that was clicked.
     */
    public void mouseClicked(ViewportCluster vpc, Viewport vp, MouseEvent e, 
			     int button)
    {
	if (vp != null && vpc != null) {

	    // Save the current Viewport state
	    vp.saveCurrentState();

	    // Rotate CW on left button and CCW otherwise
	    if (button == LEFT_MOUSE_BUTTON) {
		vp.setRotation(vp.getRotation() + 1);
	    }
	    else {
		vp.setRotation(vp.getRotation() - 1);
	    }
	    vpc.repaint(vp);
	}
    }
}
