/*
jViewBox 2.0 beta

COPYRIGHT NOTICE
Copyright (c) 2003  Jack C. Wei, Scott C. Neu, and Daniel J. Valentino

See README.license for license notices.
 */

package tools;

import java.awt.event.MouseEvent;
import org.medtoolbox.jviewbox.viewport.Viewport;
import org.medtoolbox.jviewbox.viewport.ViewportCluster;
import org.medtoolbox.jviewbox.viewport.ViewportTool;

/**
 * Tool for undoing operations on an image inside a Viewport.
 * <p>
 * When the left mouse button is clicked on a Viewport, the Viewport will
 * revert to its previous viewing state (if one exists). When any other
 * button is clicked, the Viewport will be reset to its initial state.
 *
 * @version January 8, 2004
 */
public class UndoTool extends ViewportTool
{
    /** Constructs an UndoTool. */
    public UndoTool()
    {
	super("Undo Tool", "Undo Last Image Operation", 
	      "Reset To Initial State", "Reset To Initial State");
    }

    /**
     * Invoked when a mouse button is clicked (pressed and released without
     * movement in between) on a ViewportCluster.
     *
     * @param vpc ViewportCluster which received the event.
     * @param vp Viewport which the mouse cursor was on during the event;
     *		 <code>null</code> if the mouse was outside all visible
     *		 Viewports in the ViewportCluster.
     * @param e Event created by the button click.
     * @param button The button that was clicked.
     */
    public void mouseClicked(ViewportCluster vpc, Viewport vp, MouseEvent e, 
			     int button)
    {
	if (vp != null && vpc != null) {
	    // Undo or reset
	    if (button == LEFT_MOUSE_BUTTON) {
		vp.restorePreviousState();
	    }
	    else {
		vp.resetToInitialState();
	    }

	    vpc.repaint(vp);
	}
    }
}
